.. _hello-world-example:

Hello World
===========

.. literalinclude:: helloworld.py


.. _rpc-example:

RPC
===

RPC Service
-----------

    .. literalinclude:: rpc_service.py


RPC Client
----------

    .. literalinclude:: rpc_client.py


.. _messaging-example:

Messsaging
==========

Publisher
---------

    .. literalinclude:: messaging_publisher.py

Consumer
--------

    .. literalinclude:: messaging_consumer.py
